"use client";

import { useLocale, useTranslations } from "next-intl";

import { LinkPreview } from "@/components/ui/link-preview";
import ShimmerButton from "@/components/ui/shimmer-button";

function UserAccountHeader() {
	const t = useTranslations("UserAccount");
	const locale = useLocale();

	const links = [
		{
			url: `/${locale}/cart`,
			title: t("ShoppingCart"),
		},
		{
			url: `/${locale}/user-account`,
			title: t("Purchase orders"),
		},
		{
			url: `/${locale}/user-account/points`,
			title: t("Points"),
		},
		{
			url: `/${locale}/user-account/settings`,
			title: t("Settings"),
		},
	];


	return (
		<div className="relative z-10 flex items-stretch gap-3 overflow-x-auto">
			<div className="flex items-center gap-3">
				{links?.map((ele) => (
					<div key={ele.title}>
						<LinkPreview url={`${window.location.origin}${ele.url}`}>
							<ShimmerButton
								borderRadius="8px"
								background="#fff"
								className="py-2 shadow-2xl"
							>
								<span className="whitespace-nowrap text-center text-[12px] leading-3 text-[#21242A] md:text-sm md:leading-6">
									{ele.title}
								</span>
							</ShimmerButton>
						</LinkPreview>
					</div>
				))}
			</div>
		</div>
	);
}

export default UserAccountHeader;
